summaryrefslogtreecommitdiffstats
path: root/libkonq
diff options
context:
space:
mode:
Diffstat (limited to 'libkonq')
-rw-r--r--libkonq/favicons/favicons.cpp4
-rw-r--r--libkonq/kfileivi.cc2
-rw-r--r--libkonq/kfileivi.h8
-rw-r--r--libkonq/kivdirectoryoverlay.cc6
-rw-r--r--libkonq/kivdirectoryoverlay.h2
-rw-r--r--libkonq/knewmenu.cc26
-rw-r--r--libkonq/knewmenu.h2
-rw-r--r--libkonq/konq_bgnddlg.cc14
-rw-r--r--libkonq/konq_dirpart.cc6
-rw-r--r--libkonq/konq_drag.cc16
-rw-r--r--libkonq/konq_drag.h6
-rw-r--r--libkonq/konq_filetip.cc12
-rw-r--r--libkonq/konq_historycomm.h6
-rw-r--r--libkonq/konq_historymgr.cc36
-rw-r--r--libkonq/konq_historymgr.h22
-rw-r--r--libkonq/konq_iconviewwidget.cc64
-rw-r--r--libkonq/konq_iconviewwidget.h4
-rw-r--r--libkonq/konq_operations.cc8
-rw-r--r--libkonq/konq_operations.h2
-rw-r--r--libkonq/konq_pixmapprovider.cc12
-rw-r--r--libkonq/konq_popupmenu.cc48
-rw-r--r--libkonq/konq_popupmenu.h10
-rw-r--r--libkonq/konq_propsview.cc20
-rw-r--r--libkonq/konq_propsview.h4
-rw-r--r--libkonq/konq_settings.cc4
-rw-r--r--libkonq/konq_undo.cc8
-rw-r--r--libkonq/konqbookmarkmanager.h2
27 files changed, 177 insertions, 177 deletions
diff --git a/libkonq/kfileivi.cc b/libkonq/kfileivi.cc
index 48f6d8bb6..3bc303bae 100644
--- a/libkonq/kfileivi.cc
+++ b/libkonq/kfileivi.cc
@@ -81,7 +81,7 @@ KFileIVI::~KFileIVI()
delete d;
}
-void KFileIVI::tqinvalidateThumb( int state, bool redraw )
+void KFileIVI::invalidateThumb( int state, bool redraw )
{
TQIconSet::Mode mode;
switch( state )
diff --git a/libkonq/kfileivi.h b/libkonq/kfileivi.h
index 45bcdd68b..6c16907ec 100644
--- a/libkonq/kfileivi.h
+++ b/libkonq/kfileivi.h
@@ -68,7 +68,7 @@ public:
* Changes the icon for this item.
* @param size the icon size (0 for default, otherwise size in pixels)
* @param state the state of the icon (enum in KIcon)
- * @param recalc whether to update the tqlayout of the icon view when setting the icon
+ * @param recalc whether to update the layout of the icon view when setting the icon
* @param redraw whether to redraw the item after setting the icon
*/
virtual void setIcon( int size,
@@ -80,7 +80,7 @@ public:
* Bypass @ref setIcon. This is for animated icons, you should use setIcon
* in all other cases.
* @param pixmap the pixmap to set - it SHOULD really have the right icon size!
- * @param recalc whether to update the tqlayout of the icon view when setting the icon
+ * @param recalc whether to update the layout of the icon view when setting the icon
* @param redraw whether to redraw the item after setting the icon
*/
void setPixmapDirect( const TQPixmap & pixmap,
@@ -88,14 +88,14 @@ public:
bool redraw=false);
/**
- * Notifies that all icon effects on thumbs should be tqinvalidated,
+ * Notifies that all icon effects on thumbs should be invalidated,
* e.g. because the effect settings have been changed. The thumb itself
* is assumed to be still valid (use setThumbnailPixmap() instead
* otherwise).
* @param state the state of the icon (enum in KIcon)
* @param redraw whether to redraw the item after setting the icon
*/
- void tqinvalidateThumb( int state, bool redraw = false );
+ void invalidateThumb( int state, bool redraw = false );
/**
* Our current thumbnail is not longer "current".
diff --git a/libkonq/kivdirectoryoverlay.cc b/libkonq/kivdirectoryoverlay.cc
index fd201ee02..2b32129c2 100644
--- a/libkonq/kivdirectoryoverlay.cc
+++ b/libkonq/kivdirectoryoverlay.cc
@@ -37,7 +37,7 @@
KIVDirectoryOverlay::KIVDirectoryOverlay(KFileIVI* directory)
: m_lister(0), m_foundItems(false),
- m_tqcontainsFolder(false), m_popularIcons(0)
+ m_containsFolder(false), m_popularIcons(0)
{
if (!m_lister)
{
@@ -92,7 +92,7 @@ void KIVDirectoryOverlay::slotCompleted()
// Only show folder if there's no other candidate. Most folders contain
// folders. We know this.
- if ( m_bestIcon.isNull() && m_tqcontainsFolder ) {
+ if ( m_bestIcon.isNull() && m_containsFolder ) {
m_bestIcon = "folder";
}
@@ -131,7 +131,7 @@ void KIVDirectoryOverlay::slotNewItems( const KFileItemList& items )
}
(*iconCount)++;
} else if ( file -> isDir() ) {
- m_tqcontainsFolder = true;
+ m_containsFolder = true;
}
}
diff --git a/libkonq/kivdirectoryoverlay.h b/libkonq/kivdirectoryoverlay.h
index bcf16b914..27fba34d9 100644
--- a/libkonq/kivdirectoryoverlay.h
+++ b/libkonq/kivdirectoryoverlay.h
@@ -49,7 +49,7 @@ private slots:
private:
KDirLister* m_lister;
bool m_foundItems;
- bool m_tqcontainsFolder;
+ bool m_containsFolder;
TQDict<int>* m_popularIcons;
TQString m_bestIcon;
KFileIVI* m_directory;
diff --git a/libkonq/knewmenu.cc b/libkonq/knewmenu.cc
index 30f140b6e..d592a0617 100644
--- a/libkonq/knewmenu.cc
+++ b/libkonq/knewmenu.cc
@@ -56,10 +56,10 @@ KDirWatch * KNewMenu::s_pDirWatch = 0L;
class KNewMenu::KNewMenuPrivate
{
public:
- KNewMenuPrivate() : m_tqparentWidget(0) {}
+ KNewMenuPrivate() : m_parentWidget(0) {}
KActionCollection * m_actionCollection;
TQString m_destPath;
- TQWidget *m_tqparentWidget;
+ TQWidget *m_parentWidget;
KActionMenu *m_menuDev;
};
@@ -75,13 +75,13 @@ KNewMenu::KNewMenu( KActionCollection * _collec, const char *name ) :
makeMenus();
}
-KNewMenu::KNewMenu( KActionCollection * _collec, TQWidget *tqparentWidget, const char *name ) :
+KNewMenu::KNewMenu( KActionCollection * _collec, TQWidget *parentWidget, const char *name ) :
KActionMenu( i18n( "Create New" ), "filenew", _collec, name ),
menuItemsVersion( 0 )
{
d = new KNewMenuPrivate;
d->m_actionCollection = _collec;
- d->m_tqparentWidget = tqparentWidget;
+ d->m_parentWidget = parentWidget;
makeMenus();
}
@@ -363,7 +363,7 @@ void KNewMenu::slotNewDir()
if (popupFiles.isEmpty())
return;
- KonqOperations::newDir(d->m_tqparentWidget, popupFiles.first());
+ KonqOperations::newDir(d->m_parentWidget, popupFiles.first());
}
void KNewMenu::slotNewFile()
@@ -395,8 +395,8 @@ void KNewMenu::slotNewFile()
if ( df.readType() == "Link" )
{
m_isURLDesktopFile = true;
- // entry.comment tqcontains i18n("Enter link to location (URL):"). JFYI :)
- KURLDesktopFileDlg dlg( i18n("File name:"), entry.comment, d->m_tqparentWidget );
+ // entry.comment contains i18n("Enter link to location (URL):"). JFYI :)
+ KURLDesktopFileDlg dlg( i18n("File name:"), entry.comment, d->m_parentWidget );
// TODO dlg.setCaption( i18n( ... ) );
if ( dlg.exec() )
{
@@ -419,7 +419,7 @@ void KNewMenu::slotNewFile()
//kdDebug(1203) << "second arg=" << (*it).url() << endl;
//kdDebug(1203) << "third arg=" << entry.text << endl;
TQString text = entry.text;
- text.tqreplace( "...", TQString::null ); // the ... is fine for the menu item but not for the default filename
+ text.replace( "...", TQString::null ); // the ... is fine for the menu item but not for the default filename
KURL defaultFile( *it );
defaultFile.addPath( KIO::encodeFileName( text ) );
@@ -428,7 +428,7 @@ void KNewMenu::slotNewFile()
KURL templateURL;
templateURL.setPath( entry.templatePath );
- (void) new KPropertiesDialog( templateURL, *it, text, d->m_tqparentWidget );
+ (void) new KPropertiesDialog( templateURL, *it, text, d->m_parentWidget );
}
return; // done, exit.
}
@@ -439,7 +439,7 @@ void KNewMenu::slotNewFile()
// Show the small dialog for getting the destination filename
bool ok;
TQString text = entry.text;
- text.tqreplace( "...", TQString::null ); // the ... is fine for the menu item but not for the default filename
+ text.replace( "...", TQString::null ); // the ... is fine for the menu item but not for the default filename
KURL defaultFile( *(popupFiles.begin()) );
defaultFile.addPath( KIO::encodeFileName( text ) );
@@ -447,7 +447,7 @@ void KNewMenu::slotNewFile()
text = KIO::RenameDlg::suggestName( *(popupFiles.begin()), text);
name = KInputDialog::getText( TQString::null, entry.comment,
- text, &ok, d->m_tqparentWidget );
+ text, &ok, d->m_parentWidget );
if ( !ok )
return;
}
@@ -545,7 +545,7 @@ void KURLDesktopFileDlg::initDialog( const TQString& textFileName, const TQStrin
TQLabel * label = new TQLabel( textFileName, fileNameBox );
m_leFileName = new KLineEdit( fileNameBox, 0L );
- m_leFileName->setMinimumWidth(m_leFileName->tqsizeHint().width() * 3);
+ m_leFileName->setMinimumWidth(m_leFileName->sizeHint().width() * 3);
label->setBuddy(m_leFileName); // please "scheck" style
m_leFileName->setText( defaultName );
m_leFileName->setSelection(0, m_leFileName->text().length()); // autoselect
@@ -559,7 +559,7 @@ void KURLDesktopFileDlg::initDialog( const TQString& textFileName, const TQStrin
m_urlRequester = new KURLRequester( defaultUrl, urlBox, "urlRequester" );
m_urlRequester->setMode( KFile::File | KFile::Directory );
- m_urlRequester->setMinimumWidth( m_urlRequester->tqsizeHint().width() * 3 );
+ m_urlRequester->setMinimumWidth( m_urlRequester->sizeHint().width() * 3 );
connect( m_urlRequester->lineEdit(), TQT_SIGNAL(textChanged(const TQString&)),
TQT_SLOT(slotURLTextChanged(const TQString&)) );
label->setBuddy(m_urlRequester); // please "scheck" style
diff --git a/libkonq/knewmenu.h b/libkonq/knewmenu.h
index 3c1b0a78b..6935ae7a4 100644
--- a/libkonq/knewmenu.h
+++ b/libkonq/knewmenu.h
@@ -58,7 +58,7 @@ public:
* Constructor
*/
KNewMenu( KActionCollection * _collec, const char *name=0L );
- KNewMenu( KActionCollection * _collec, TQWidget *tqparentWidget, const char *name=0L );
+ KNewMenu( KActionCollection * _collec, TQWidget *parentWidget, const char *name=0L );
virtual ~KNewMenu();
/**
diff --git a/libkonq/konq_bgnddlg.cc b/libkonq/konq_bgnddlg.cc
index 254e3f7dc..ca21c69a3 100644
--- a/libkonq/konq_bgnddlg.cc
+++ b/libkonq/konq_bgnddlg.cc
@@ -48,10 +48,10 @@ KonqBgndDialog::KonqBgndDialog( TQWidget* parent,
m_buttonGroup = new TQButtonGroup( i18n("Background"), page );
m_buttonGroup->setColumnLayout( 0, Qt::Vertical );
- m_buttonGroup->tqlayout()->setMargin( KDialog::marginHint() );
- m_buttonGroup->tqlayout()->setSpacing( KDialog::spacingHint() );
- TQGridLayout* groupLayout = new TQGridLayout( m_buttonGroup->tqlayout() );
- groupLayout->tqsetAlignment( Qt::AlignTop );
+ m_buttonGroup->layout()->setMargin( KDialog::marginHint() );
+ m_buttonGroup->layout()->setSpacing( KDialog::spacingHint() );
+ TQGridLayout* groupLayout = new TQGridLayout( m_buttonGroup->layout() );
+ groupLayout->setAlignment( Qt::AlignTop );
mainLayout->addWidget( m_buttonGroup );
connect( m_buttonGroup, TQT_SIGNAL( clicked(int) ),
@@ -61,7 +61,7 @@ KonqBgndDialog::KonqBgndDialog( TQWidget* parent,
m_radioColor = new TQRadioButton( i18n("Co&lor:"), m_buttonGroup );
groupLayout->addWidget( m_radioColor, 0, 0 );
m_buttonColor = new KColorButton( theColor, defaultColor, m_buttonGroup );
- m_buttonColor->tqsetSizePolicy( TQSizePolicy::Preferred,
+ m_buttonColor->setSizePolicy( TQSizePolicy::Preferred,
TQSizePolicy::Minimum );
groupLayout->addWidget( m_buttonColor, 0, 1 );
@@ -90,14 +90,14 @@ KonqBgndDialog::KonqBgndDialog( TQWidget* parent,
TQLabel* lbl = new TQLabel( i18n("Preview"), page );
hlay->addWidget( lbl );
TQFrame* frame = new TQFrame( page );
- frame->tqsetSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Minimum );
+ frame->setSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Minimum );
frame->setFrameShape( TQFrame::HLine );
frame->setFrameShadow( TQFrame::Sunken );
hlay->addWidget( frame );
// preview frame
m_preview = new TQFrame( page );
- m_preview->tqsetSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding );
+ m_preview->setSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding );
m_preview->setMinimumSize( 370, 180 );
m_preview->setFrameShape( TQFrame::Panel );
m_preview->setFrameShadow( TQFrame::Raised );
diff --git a/libkonq/konq_dirpart.cc b/libkonq/konq_dirpart.cc
index 811e5b6a6..d64dde7ef 100644
--- a/libkonq/konq_dirpart.cc
+++ b/libkonq/konq_dirpart.cc
@@ -190,7 +190,7 @@ KonqDirPart::KonqDirPart( TQObject *parent, const char *name )
kdDebug(1203) << "the icon theme handles the following sizes:" << avSizes << endl;
if (avSizes.count() < 10) {
// Use the icon sizes supplied by the theme.
- // If avSizes tqcontains more than 10 entries, assume a scalable
+ // If avSizes contains more than 10 entries, assume a scalable
// icon theme.
TQValueList<int>::Iterator it;
for (i=1, it=avSizes.begin(); (it!=avSizes.end()) && (i<7); it++, i++)
@@ -301,7 +301,7 @@ void KonqDirPart::slotBackgroundSettings()
m_pProps->setBgPixmapFile( dlg->pixmapFile() );
}
m_pProps->applyColors( scrollWidget()->viewport() );
- scrollWidget()->viewport()->tqrepaint();
+ scrollWidget()->viewport()->repaint();
}
delete dlg;
@@ -548,7 +548,7 @@ void KonqDirPart::slotIconSizeToggled( bool toggleOn )
// This slot is called when an iconsize action is checked or by calling
// action->setChecked(false) (previously true). So we must filter out
- // the 'untoggled' case to prevent odd results here (tqrepaints/loops!)
+ // the 'untoggled' case to prevent odd results here (repaints/loops!)
if ( !toggleOn )
return;
diff --git a/libkonq/konq_drag.cc b/libkonq/konq_drag.cc
index 07a3e8bda..0fdca5722 100644
--- a/libkonq/konq_drag.cc
+++ b/libkonq/konq_drag.cc
@@ -47,12 +47,12 @@ const char* KonqIconDrag::format( int i ) const
else return 0;
}
-TQByteArray KonqIconDrag::tqencodedData( const char* mime ) const
+TQByteArray KonqIconDrag::encodedData( const char* mime ) const
{
TQByteArray a;
TQCString mimetype( mime );
if ( mimetype == "application/x-qiconlist" )
- a = TQIconDrag::tqencodedData( mime );
+ a = TQIconDrag::encodedData( mime );
else if ( mimetype == "text/uri-list" ) {
TQCString s = urls.join( "\r\n" ).latin1();
if( urls.count() > 0 )
@@ -145,7 +145,7 @@ const char* KonqIconDrag2::format( int i ) const
return KonqIconDrag::format( i );
}
-TQByteArray KonqIconDrag2::tqencodedData( const char* mime ) const
+TQByteArray KonqIconDrag2::encodedData( const char* mime ) const
{
TQCString mimetype( mime );
if ( mimetype == "application/x-kde-urilist" )
@@ -164,7 +164,7 @@ TQByteArray KonqIconDrag2::tqencodedData( const char* mime ) const
a[c] = 0;
return a;
}
- return KonqIconDrag::tqencodedData( mime );
+ return KonqIconDrag::encodedData( mime );
}
//
@@ -223,7 +223,7 @@ const char* KonqDrag::format( int i ) const
else return 0;
}
-TQByteArray KonqDrag::tqencodedData( const char* mime ) const
+TQByteArray KonqDrag::encodedData( const char* mime ) const
{
TQByteArray a;
TQCString mimetype( mime );
@@ -232,7 +232,7 @@ TQByteArray KonqDrag::tqencodedData( const char* mime ) const
// Code taken from TQUriDrag::setUris
int c=0;
for (TQStrListIterator it(m_urls); *it; ++it) {
- int l = tqstrlen(*it);
+ int l = qstrlen(*it);
a.resize(c+l+2);
memcpy(a.data()+c,*it,l);
memcpy(a.data()+c+l,"\r\n",2);
@@ -243,7 +243,7 @@ TQByteArray KonqDrag::tqencodedData( const char* mime ) const
}
else if ( mimetype == "application/x-kde-urilist" )
{
- return TQUriDrag::tqencodedData( "text/uri-list" );
+ return TQUriDrag::encodedData( "text/uri-list" );
}
else if ( mimetype == "application/x-kde-cutselection" )
{
@@ -271,7 +271,7 @@ TQByteArray KonqDrag::tqencodedData( const char* mime ) const
bool KonqDrag::decodeIsCutSelection( const TQMimeSource *e )
{
- TQByteArray a = e->tqencodedData( "application/x-kde-cutselection" );
+ TQByteArray a = e->encodedData( "application/x-kde-cutselection" );
if ( a.isEmpty() )
return false;
else
diff --git a/libkonq/konq_drag.h b/libkonq/konq_drag.h
index 685569db9..e5e49a837 100644
--- a/libkonq/konq_drag.h
+++ b/libkonq/konq_drag.h
@@ -44,7 +44,7 @@ public:
virtual ~KonqIconDrag() {}
const char* format( int i ) const;
- TQByteArray tqencodedData( const char* mime ) const;
+ TQByteArray encodedData( const char* mime ) const;
void append( const TQIconDragItem &item, const TQRect &pr,
const TQRect &tr, const TQString &url );
@@ -72,7 +72,7 @@ public:
virtual ~KonqIconDrag2() {}
virtual const char* format( int i ) const;
- virtual TQByteArray tqencodedData( const char* mime ) const;
+ virtual TQByteArray encodedData( const char* mime ) const;
void append( const TQIconDragItem &item, const TQRect &pr,
const TQRect &tr, const TQString &url, const KURL &mostLocalURL );
@@ -107,7 +107,7 @@ public:
virtual ~KonqDrag() {}
virtual const char* format( int i ) const;
- virtual TQByteArray tqencodedData( const char* mime ) const;
+ virtual TQByteArray encodedData( const char* mime ) const;
void setMoveSelection( bool move ) { m_bCutSelection = move; }
diff --git a/libkonq/konq_filetip.cc b/libkonq/konq_filetip.cc
index b6aac84e3..81262ae99 100644
--- a/libkonq/konq_filetip.cc
+++ b/libkonq/konq_filetip.cc
@@ -49,12 +49,12 @@ KonqFileTip::KonqFileTip( TQScrollView* parent )
{
m_iconLabel = new TQLabel(this);
m_textLabel = new TQLabel(this);
- m_textLabel->tqsetAlignment(Qt::AlignAuto | Qt::AlignTop);
+ m_textLabel->setAlignment(Qt::AlignAuto | Qt::AlignTop);
- TQGridLayout* tqlayout = new TQGridLayout(this, 1, 2, 8, 0);
- tqlayout->addWidget(m_iconLabel, 0, 0);
- tqlayout->addWidget(m_textLabel, 0, 1);
- tqlayout->setResizeMode(TQLayout::Fixed);
+ TQGridLayout* layout = new TQGridLayout(this, 1, 2, 8, 0);
+ layout->addWidget(m_iconLabel, 0, 0);
+ layout->addWidget(m_textLabel, 0, 1);
+ layout->setResizeMode(TQLayout::Fixed);
setPalette( TQToolTip::palette() );
setMargin( 1 );
@@ -189,7 +189,7 @@ void KonqFileTip::drawContents( TQPainter *p )
}
if ( m_corners[m_corner].isNull())
- m_corners[m_corner].load( locate( "data", TQString::tqfromLatin1( "konqueror/pics/%1.png" ).arg( names[m_corner] ) ) );
+ m_corners[m_corner].load( locate( "data", TQString::fromLatin1( "konqueror/pics/%1.png" ).arg( names[m_corner] ) ) );
TQPixmap &pix = m_corners[m_corner];
diff --git a/libkonq/konq_historycomm.h b/libkonq/konq_historycomm.h
index 96c3a375e..ea2a387df 100644
--- a/libkonq/konq_historycomm.h
+++ b/libkonq/konq_historycomm.h
@@ -37,7 +37,7 @@ public:
KURL url;
TQString typedURL;
TQString title;
- TQ_UINT32 numberOfTimesVisited;
+ Q_UINT32 numberOfTimesVisited;
TQDateTime firstVisited;
TQDateTime lastVisited;
};
@@ -65,8 +65,8 @@ protected:
k_dcop:
virtual ASYNC notifyHistoryEntry( KonqHistoryEntry e, TQCString saveId) = 0;
- virtual ASYNC notifyMaxCount( TQ_UINT32 count, TQCString saveId ) = 0;
- virtual ASYNC notifyMaxAge( TQ_UINT32 days, TQCString saveId ) = 0;
+ virtual ASYNC notifyMaxCount( Q_UINT32 count, TQCString saveId ) = 0;
+ virtual ASYNC notifyMaxAge( Q_UINT32 days, TQCString saveId ) = 0;
virtual ASYNC notifyClear( TQCString saveId ) = 0;
virtual ASYNC notifyRemove( KURL url, TQCString saveId ) = 0;
virtual ASYNC notifyRemove( KURL::List url, TQCString saveId ) = 0;
diff --git a/libkonq/konq_historymgr.cc b/libkonq/konq_historymgr.cc
index 1b590fc61..b971d39b3 100644
--- a/libkonq/konq_historymgr.cc
+++ b/libkonq/konq_historymgr.cc
@@ -31,7 +31,7 @@
#include "konqbookmarkmanager.h"
-const TQ_UINT32 KonqHistoryManager::s_historyVersion = 3;
+const Q_UINT32 KonqHistoryManager::s_historyVersion = 3;
KonqHistoryManager::KonqHistoryManager( TQObject *parent, const char *name )
: KParts::HistoryProvider( parent, name ),
@@ -48,7 +48,7 @@ KonqHistoryManager::KonqHistoryManager( TQObject *parent, const char *name )
m_history.setAutoDelete( true );
m_filename = locateLocal( "data",
- TQString::tqfromLatin1("konqueror/konq_history" ));
+ TQString::fromLatin1("konqueror/konq_history" ));
if ( !kapp->dcopClient()->isAttached() )
kapp->dcopClient()->attach();
@@ -102,7 +102,7 @@ bool KonqHistoryManager::loadHistory()
TQDataStream crcStream( data, IO_ReadOnly );
if ( !fileStream.atEnd() ) {
- TQ_UINT32 version;
+ Q_UINT32 version;
fileStream >> version;
TQDataStream *stream = &fileStream;
@@ -111,7 +111,7 @@ bool KonqHistoryManager::loadHistory()
bool crcOk = false;
if ( version == 2 || version == 3) {
- TQ_UINT32 crc;
+ Q_UINT32 crc;
crcChecked = true;
fileStream >> crc >> data;
crcOk = crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() ) == crc;
@@ -132,7 +132,7 @@ bool KonqHistoryManager::loadHistory()
// binary file, this would make backups impossible (they would clear
// themselves on startup, because all entries expire).
// [But V1 and V2 formats did it, so we do a dummy read]
- TQ_UINT32 dummy;
+ Q_UINT32 dummy;
*stream >> dummy;
*stream >> dummy;
@@ -224,7 +224,7 @@ bool KonqHistoryManager::saveHistory()
//For DCOP, transfer strings instead - wire compat.
KonqHistoryEntry::marshalURLAsStrings = true;
- TQ_UINT32 crc = crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() );
+ Q_UINT32 crc = crc32( 0, reinterpret_cast<unsigned char *>( data.data() ), data.size() );
*fileStream << crc << data;
file.close();
@@ -295,11 +295,11 @@ void KonqHistoryManager::addToHistory( bool pending, const KURL& _url,
// konqueror's window caption).
if ( !pending && u != title )
entry.title = title;
- entry.firstVisited = TQDateTime::tqcurrentDateTime();
+ entry.firstVisited = TQDateTime::currentDateTime();
entry.lastVisited = entry.firstVisited;
// always remove from pending if available, otherwise the else branch leaks
- // if the map already tqcontains an entry for this key.
+ // if the map already contains an entry for this key.
TQMapIterator<TQString,KonqHistoryEntry*> it = m_pending.find( u );
if ( it != m_pending.end() ) {
delete it.data();
@@ -342,7 +342,7 @@ void KonqHistoryManager::insert( const TQString& url )
// Local URL -> add to history
KonqHistoryEntry entry;
entry.url = u;
- entry.firstVisited = TQDateTime::tqcurrentDateTime();
+ entry.firstVisited = TQDateTime::currentDateTime();
entry.lastVisited = entry.firstVisited;
emitAddToHistory( entry );
}
@@ -419,22 +419,22 @@ void KonqHistoryManager::emitClear()
"notifyClear(TQCString)", data );
}
-void KonqHistoryManager::emitSetMaxCount( TQ_UINT32 count )
+void KonqHistoryManager::emitSetMaxCount( Q_UINT32 count )
{
TQByteArray data;
TQDataStream stream( data, IO_WriteOnly );
stream << count << objId();
kapp->dcopClient()->send( "konqueror*", "KonqHistoryManager",
- "notifyMaxCount(TQ_UINT32, TQCString)", data );
+ "notifyMaxCount(Q_UINT32, TQCString)", data );
}
-void KonqHistoryManager::emitSetMaxAge( TQ_UINT32 days )
+void KonqHistoryManager::emitSetMaxAge( Q_UINT32 days )
{
TQByteArray data;
TQDataStream stream( data, IO_WriteOnly );
stream << days << objId();
kapp->dcopClient()->send( "konqueror*", "KonqHistoryManager",
- "notifyMaxAge(TQ_UINT32, TQCString)", data );
+ "notifyMaxAge(Q_UINT32, TQCString)", data );
}
///////////////////////////////////////////////////////////////////
@@ -487,7 +487,7 @@ void KonqHistoryManager::notifyHistoryEntry( KonqHistoryEntry e,
emit entryAdded( entry );
}
-void KonqHistoryManager::notifyMaxCount( TQ_UINT32 count, TQCString )
+void KonqHistoryManager::notifyMaxCount( Q_UINT32 count, TQCString )
{
m_maxCount = count;
clearPending();
@@ -503,7 +503,7 @@ void KonqHistoryManager::notifyMaxCount( TQ_UINT32 count, TQCString )
}
}
-void KonqHistoryManager::notifyMaxAge( TQ_UINT32 days, TQCString )
+void KonqHistoryManager::notifyMaxAge( Q_UINT32 days, TQCString )
{
m_maxAgeDays = days;
clearPending();
@@ -589,7 +589,7 @@ void KonqHistoryManager::notifyRemove( KURL::List urls, TQCString )
// compatibility fallback, try to load the old completion history
bool KonqHistoryManager::loadFallback()
{
- TQString file = locateLocal( "config", TQString::tqfromLatin1("konq_history"));
+ TQString file = locateLocal( "config", TQString::fromLatin1("konq_history"));
if ( file.isEmpty() )
return false;
@@ -646,7 +646,7 @@ KonqHistoryEntry * KonqHistoryManager::createFallbackEntry(const TQString& item)
entry->url = u;
entry->numberOfTimesVisited = weight;
// to make it not expire immediately...
- entry->lastVisited = TQDateTime::tqcurrentDateTime();
+ entry->lastVisited = TQDateTime::currentDateTime();
}
return entry;
@@ -655,7 +655,7 @@ KonqHistoryEntry * KonqHistoryManager::createFallbackEntry(const TQString& item)
KonqHistoryEntry * KonqHistoryManager::findEntry( const KURL& url )
{
// small optimization (dict lookup) for items _not_ in our history
- if ( !KParts::HistoryProvider::tqcontains( url.url() ) )
+ if ( !KParts::HistoryProvider::contains( url.url() ) )
return 0L;
return m_history.findEntry( url );
diff --git a/libkonq/konq_historymgr.h b/libkonq/konq_historymgr.h
index 46c603f20..11b14603b 100644
--- a/libkonq/konq_historymgr.h
+++ b/libkonq/konq_historymgr.h
@@ -91,7 +91,7 @@ public:
*
* The history is saved after receiving the DCOP call.
*/
- void emitSetMaxCount( TQ_UINT32 count );
+ void emitSetMaxCount( Q_UINT32 count );
/**
* Sets a new maximum age of history entries and removes all entries that
@@ -102,7 +102,7 @@ public:
*
* The history is saved after receiving the DCOP call.
*/
- void emitSetMaxAge( TQ_UINT32 days );
+ void emitSetMaxAge( Q_UINT32 days );
/**
* Removes the history entry for @p url, if existant. Tells all other
@@ -123,12 +123,12 @@ public:
/**
* @returns the current maximum number of history entries.
*/
- TQ_UINT32 maxCount() const { return m_maxCount; }
+ Q_UINT32 maxCount() const { return m_maxCount; }
/**
* @returns the current maximum age (in days) of history entries.
*/
- TQ_UINT32 maxAge() const { return m_maxAgeDays; }
+ Q_UINT32 maxAge() const { return m_maxAgeDays; }
/**
* Adds a pending entry to the history. Pending means, that the entry is
@@ -236,7 +236,7 @@ protected:
*/
inline bool isExpired( KonqHistoryEntry *entry ) {
return (entry && m_maxAgeDays > 0 && entry->lastVisited <
- TQDate::tqcurrentDate().addDays( -m_maxAgeDays ));
+ TQDate::currentDate().addDays( -m_maxAgeDays ));
}
/**
@@ -259,13 +259,13 @@ protected:
* Called when the configuration of the maximum count changed.
* Called via DCOP by some config-module
*/
- virtual void notifyMaxCount( TQ_UINT32 count, TQCString saveId );
+ virtual void notifyMaxCount( Q_UINT32 count, TQCString saveId );
/**
* Called when the configuration of the maximum age of history-entries
* changed. Called via DCOP by some config-module
*/
- virtual void notifyMaxAge( TQ_UINT32 days, TQCString saveId );
+ virtual void notifyMaxAge( Q_UINT32 days, TQCString saveId );
/**
* Clears the history completely. Called via DCOP by some config-module
@@ -327,7 +327,7 @@ protected:
private slots:
/**
* Called by the updateTimer to emit the KParts::HistoryProvider::updated()
- * signal so that khtml can tqrepaint the updated links.
+ * signal so that khtml can repaint the updated links.
*/
void slotEmitUpdated();
@@ -367,8 +367,8 @@ private:
*/
TQMap<TQString,KonqHistoryEntry*> m_pending;
- TQ_UINT32 m_maxCount; // maximum of history entries
- TQ_UINT32 m_maxAgeDays; // maximum age of a history entry
+ Q_UINT32 m_maxCount; // maximum of history entries
+ Q_UINT32 m_maxAgeDays; // maximum age of a history entry
KCompletion *m_pCompletion; // the completion object we sync with
@@ -378,7 +378,7 @@ private:
*/
TQTimer *m_updateTimer;
- static const TQ_UINT32 s_historyVersion;
+ static const Q_UINT32 s_historyVersion;
};
diff --git a/libkonq/konq_iconviewwidget.h b/libkonq/konq_iconviewwidget.h
index 16cdef63d..04db9029a 100644
--- a/libkonq/konq_iconviewwidget.h
+++ b/libkonq/konq_iconviewwidget.h
@@ -140,7 +140,7 @@ public:
int gridXValue() const;
/**
- * Calculate the tqgeometry of the fixed grid that is used to line up the
+ * Calculate the geometry of the fixed grid that is used to line up the
* icons, for example when using the lineupIcons() method.
*
* @param x
@@ -296,7 +296,7 @@ protected slots:
void slotPreviewResult();
void slotMovieUpdate( const TQRect& rect );
- void slotMovietqStatus( int status );
+ void slotMovieStatus( int status );
void slotReenableAnimation();
void slotAboutToCreate(const TQPoint &pos, const TQValueList<KIO::CopyInfo> &files);
diff --git a/libkonq/konq_operations.cc b/libkonq/konq_operations.cc
index 7e52be950..6a1ebcdb6 100644
--- a/libkonq/konq_operations.cc
+++ b/libkonq/konq_operations.cc
@@ -76,7 +76,7 @@ KonqOperations::~KonqOperations()
void KonqOperations::editMimeType( const TQString & mimeType )
{
- TQString keditfiletype = TQString::tqfromLatin1("keditfiletype");
+ TQString keditfiletype = TQString::fromLatin1("keditfiletype");
KRun::runCommand( keditfiletype + " " + KProcess::quote(mimeType),
keditfiletype, keditfiletype /*unused*/);
}
@@ -185,7 +185,7 @@ void KonqOperations::_del( int method, const KURL::List & _selectedURLs, Confirm
return;
}
- if ( askDeleteConfirmation( selectedURLs, method, confirmation, tqparentWidget() ) )
+ if ( askDeleteConfirmation( selectedURLs, method, confirmation, parentWidget() ) )
{
//m_srcURLs = selectedURLs;
KIO::Job *job;
@@ -525,7 +525,7 @@ void KonqOperations::doFileCopy()
}
m_method = TRASH;
- if ( askDeleteConfirmation( mlst, TRASH, DEFAULT_CONFIRMATION, tqparentWidget() ) )
+ if ( askDeleteConfirmation( mlst, TRASH, DEFAULT_CONFIRMATION, parentWidget() ) )
action = TQDropEvent::Move;
else
{
@@ -815,7 +815,7 @@ void KonqMultiRestoreJob::slotResult( KIO::Job *job )
slotStart();
}
-TQWidget* KonqOperations::tqparentWidget() const
+TQWidget* KonqOperations::parentWidget() const
{
return static_cast<TQWidget *>( parent() );
}
diff --git a/libkonq/konq_operations.h b/libkonq/konq_operations.h
index ec04033df..f9134bcde 100644
--- a/libkonq/konq_operations.h
+++ b/libkonq/konq_operations.h
@@ -173,7 +173,7 @@ protected:
void setPasteInfo( KIOPasteInfo * info ) { m_pasteInfo = info; }
private:
- TQWidget* tqparentWidget() const;
+ TQWidget* parentWidget() const;
protected slots:
diff --git a/libkonq/konq_pixmapprovider.cc b/libkonq/konq_pixmapprovider.cc
index 9ce147b07..3cff83453 100644
--- a/libkonq/konq_pixmapprovider.cc
+++ b/libkonq/konq_pixmapprovider.cc
@@ -182,13 +182,13 @@ TQPixmap KonqPixmapProvider::loadIcon( const TQString& url, const TQString& icon
int x = big.width() - small.width();
int y = 0;
- if ( big.tqmask() ) {
- TQBitmap tqmask = *big.tqmask();
- bitBlt( &tqmask, x, y,
- small.tqmask() ? const_cast<TQBitmap *>(small.tqmask()) : &small, 0, 0,
+ if ( big.mask() ) {
+ TQBitmap mask = *big.mask();
+ bitBlt( &mask, x, y,
+ small.mask() ? const_cast<TQBitmap *>(small.mask()) : &small, 0, 0,
small.width(), small.height(),
- small.tqmask() ? OrROP : SetROP );
- big.setMask( tqmask );
+ small.mask() ? OrROP : SetROP );
+ big.setMask( mask );
}
bitBlt( &big, x, y, &small );
diff --git a/libkonq/konq_popupmenu.cc b/libkonq/konq_popupmenu.cc
index 6d1057c04..044bda9d2 100644
--- a/libkonq/konq_popupmenu.cc
+++ b/libkonq/konq_popupmenu.cc
@@ -95,12 +95,12 @@ public:
class KonqPopupMenu::KonqPopupMenuPrivate
{
public:
- KonqPopupMenuPrivate() : m_tqparentWidget( 0 ),
+ KonqPopupMenuPrivate() : m_parentWidget( 0 ),
m_itemFlags( KParts::BrowserExtension::DefaultPopupItems )
{
}
TQString m_urlTitle;
- TQWidget *m_tqparentWidget;
+ TQWidget *m_parentWidget;
KParts::BrowserExtension::PopupFlags m_itemFlags;
};
@@ -199,30 +199,30 @@ KonqPopupMenu::KonqPopupMenu( KBookmarkManager *mgr, const KFileItemList &items,
KURL viewURL,
KActionCollection & actions,
KNewMenu * newMenu,
- TQWidget * tqparentWidget,
+ TQWidget * parentWidget,
bool showProperties )
- : TQPopupMenu( tqparentWidget, "konq_popupmenu" ), m_actions( actions ), m_ownActions( static_cast<TQWidget *>( 0 ), "KonqPopupMenu::m_ownActions" ), m_pMenuNew( newMenu ), m_sViewURL(viewURL), m_lstItems(items), m_pManager(mgr)
+ : TQPopupMenu( parentWidget, "konq_popupmenu" ), m_actions( actions ), m_ownActions( static_cast<TQWidget *>( 0 ), "KonqPopupMenu::m_ownActions" ), m_pMenuNew( newMenu ), m_sViewURL(viewURL), m_lstItems(items), m_pManager(mgr)
{
KonqPopupFlags kpf = ( showProperties ? ShowProperties : IsLink ) | ShowNewWindow;
- init(tqparentWidget, kpf, KParts::BrowserExtension::DefaultPopupItems);
+ init(parentWidget, kpf, KParts::BrowserExtension::DefaultPopupItems);
}
KonqPopupMenu::KonqPopupMenu( KBookmarkManager *mgr, const KFileItemList &items,
const KURL& viewURL,
KActionCollection & actions,
KNewMenu * newMenu,
- TQWidget * tqparentWidget,
+ TQWidget * parentWidget,
KonqPopupFlags kpf,
KParts::BrowserExtension::PopupFlags flags)
- : TQPopupMenu( tqparentWidget, "konq_popupmenu" ), m_actions( actions ), m_ownActions( static_cast<TQWidget *>( 0 ), "KonqPopupMenu::m_ownActions" ), m_pMenuNew( newMenu ), m_sViewURL(viewURL), m_lstItems(items), m_pManager(mgr)
+ : TQPopupMenu( parentWidget, "konq_popupmenu" ), m_actions( actions ), m_ownActions( static_cast<TQWidget *>( 0 ), "KonqPopupMenu::m_ownActions" ), m_pMenuNew( newMenu ), m_sViewURL(viewURL), m_lstItems(items), m_pManager(mgr)
{
- init(tqparentWidget, kpf, flags);
+ init(parentWidget, kpf, flags);
}
-void KonqPopupMenu::init (TQWidget * tqparentWidget, KonqPopupFlags kpf, KParts::BrowserExtension::PopupFlags flags)
+void KonqPopupMenu::init (TQWidget * parentWidget, KonqPopupFlags kpf, KParts::BrowserExtension::PopupFlags flags)
{
d = new KonqPopupMenuPrivate;
- d->m_tqparentWidget = tqparentWidget;
+ d->m_parentWidget = parentWidget;
d->m_itemFlags = flags;
setup(kpf);
}
@@ -280,7 +280,7 @@ int KonqPopupMenu::insertServices(const ServiceList& list,
TQCString name;
name.setNum( id );
name.prepend( isBuiltin ? "builtinservice_" : "userservice_" );
- KAction * act = new KAction( TQString((*it).m_strName).tqreplace('&',"&&"), 0,
+ KAction * act = new KAction( TQString((*it).m_strName).replace('&',"&&"), 0,
this, TQT_SLOT( slotRunService() ),
&m_ownActions, name );
@@ -354,7 +354,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
m_pluginList.setAutoDelete( true );
m_ownActions.setHighlightingEnabled( true );
- attrName = TQString::tqfromLatin1( "name" );
+ attrName = TQString::fromLatin1( "name" );
prepareXMLGUIStuff();
m_builder = new KonqPopupMenuGUIBuilder( this );
@@ -584,7 +584,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
{
act = new KAction( i18n( "&Empty Trash Bin" ), "emptytrash", 0, this, TQT_SLOT( slotPopupEmptyTrashBin() ), &m_ownActions, "empytrash" );
KSimpleConfig trashConfig( "trashrc", true );
- trashConfig.setGroup( "tqStatus" );
+ trashConfig.setGroup( "Status" );
act->setEnabled( !trashConfig.readBoolEntry( "Empty", true ) );
addAction( act );
}
@@ -720,7 +720,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
TQCString object = dcopcall.section(' ', 1,-2).utf8();
TQString function = dcopcall.section(' ', -1);
if(!function.endsWith("(KURL::List)")) {
- kdWarning() << "Desktop file " << *eIt << " tqcontains an invalid X-KDE-ShowIfDcopCall - the function must take the exact parameter (KURL::List) and must be specified." << endl;
+ kdWarning() << "Desktop file " << *eIt << " contains an invalid X-KDE-ShowIfDcopCall - the function must take the exact parameter (KURL::List) and must be specified." << endl;
continue; //Be safe.
}
@@ -741,7 +741,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
else if ( cfg.hasKey( "X-KDE-Protocols" ) )
{
TQStringList protocols = TQStringList::split( "," , cfg.readEntry( "X-KDE-Protocols" ) );
- if ( !protocols.tqcontains( urlForServiceMenu.protocol() ) )
+ if ( !protocols.contains( urlForServiceMenu.protocol() ) )
continue;
}
else if ( urlForServiceMenu.protocol() == "trash" || urlForServiceMenu.url().startsWith( "system:/trash" ) )
@@ -755,7 +755,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
if ( cfg.hasKey( "X-KDE-Require" ) )
{
const TQStringList capabilities = cfg.readListEntry( "X-KDE-Require" );
- if ( capabilities.tqcontains( "Write" ) && !sWriting )
+ if ( capabilities.contains( "Write" ) && !sWriting )
continue;
}
if ( (cfg.hasKey( "Actions" ) || cfg.hasKey( "X-KDE-GetActionMenu") ) && cfg.hasKey( "ServiceTypes" ) )
@@ -882,20 +882,20 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
const TQString onlyShowIn = service->property("OnlyShowIn", TQVariant::String).toString();
if ( !onlyShowIn.isEmpty() ) {
const TQStringList aList = TQStringList::split(';', onlyShowIn);
- if (!aList.tqcontains("KDE"))
+ if (!aList.contains("KDE"))
continue;
}
const TQString notShowIn = service->property("NotShowIn", TQVariant::String).toString();
if ( !notShowIn.isEmpty() ) {
const TQStringList aList = TQStringList::split(';', notShowIn);
- if (aList.tqcontains("KDE"))
+ if (aList.contains("KDE"))
continue;
}
TQCString nam;
nam.setNum( id );
- TQString actionName( (*it)->name().tqreplace("&", "&&") );
+ TQString actionName( (*it)->name().replace("&", "&&") );
if ( menu == m_menuElement ) // no submenu -> prefix single offer
actionName = i18n( "Open with %1" ).arg( actionName );
@@ -1034,7 +1034,7 @@ void KonqPopupMenu::slotPopupNewDir()
if (m_lstPopupURLs.empty())
return;
- KonqOperations::newDir(d->m_tqparentWidget, m_lstPopupURLs.first());
+ KonqOperations::newDir(d->m_parentWidget, m_lstPopupURLs.first());
}
void KonqPopupMenu::slotPopupEmptyTrashBin()
@@ -1115,10 +1115,10 @@ KPropertiesDialog* KonqPopupMenu::showPropertiesDialog()
if (item->entry().count() == 0) // this item wasn't listed by a slave
{
// KPropertiesDialog will use stat to get more info on the file
- return new KPropertiesDialog( item->url(), d->m_tqparentWidget );
+ return new KPropertiesDialog( item->url(), d->m_parentWidget );
}
}
- return new KPropertiesDialog( m_lstItems, d->m_tqparentWidget );
+ return new KPropertiesDialog( m_lstItems, d->m_parentWidget );
}
KAction *KonqPopupMenu::action( const TQDomElement &element ) const
@@ -1156,7 +1156,7 @@ void KonqPopupMenu::addPlugins()
//search for a plugin with the right protocol
KTrader::OfferList plugin_offers;
unsigned int pluginCount = 0;
- plugin_offers = KTrader::self()->query( m_sMimeType.isNull() ? TQString::tqfromLatin1( "all/all" ) : m_sMimeType, "'KonqPopupMenu/Plugin' in ServiceTypes");
+ plugin_offers = KTrader::self()->query( m_sMimeType.isNull() ? TQString::fromLatin1( "all/all" ) : m_sMimeType, "'KonqPopupMenu/Plugin' in ServiceTypes");
if ( plugin_offers.isEmpty() )
return; // no plugins installed do not bother about it
@@ -1175,7 +1175,7 @@ void KonqPopupMenu::addPlugins()
if ( !plugin )
continue;
// This make the kuick plugin insert its stuff above "Properties"
- TQString pluginClientName = TQString::tqfromLatin1( "Plugin%1" ).arg( pluginCount );
+ TQString pluginClientName = TQString::fromLatin1( "Plugin%1" ).arg( pluginCount );
addMerge( pluginClientName );
plugin->domDocument().documentElement().setAttribute( "name", pluginClientName );
m_pluginList.append( plugin );
diff --git a/libkonq/konq_propsview.cc b/libkonq/konq_propsview.cc
index e7096a3f8..303fe044f 100644
--- a/libkonq/konq_propsview.cc
+++ b/libkonq/konq_propsview.cc
@@ -103,7 +103,7 @@ KonqPropsView::KonqPropsView( KInstance * instance, KonqPropsView * defaultProps
//the default-to-off bias to propagate up.
if (!config->readBoolEntry("EnableSoundPreviews", false))
{
- if (!m_dontPreview.tqcontains("audio/"))
+ if (!m_dontPreview.contains("audio/"))
m_dontPreview.append("audio/");
}
@@ -234,13 +234,13 @@ bool KonqPropsView::enterDir( const KURL & dir )
{
if (!config->readBoolEntry("EnableSoundPreviews", false))
- if (!m_dontPreview.tqcontains("audio/"))
+ if (!m_dontPreview.contains("audio/"))
m_dontPreview.append("audio/");
}
else
{
- if (m_defaultProps->m_dontPreview.tqcontains("audio/"))
- if (!m_dontPreview.tqcontains("audio/"))
+ if (m_defaultProps->m_dontPreview.contains("audio/"))
+ if (!m_dontPreview.contains("audio/"))
m_dontPreview.append("audio/");
}
}
@@ -395,7 +395,7 @@ void KonqPropsView::setShowingDirectoryOverlays( bool show )
void KonqPropsView::setShowingPreview( const TQString &preview, bool show )
{
- if ( m_dontPreview.tqcontains( preview ) != show )
+ if ( m_dontPreview.contains( preview ) != show )
return;
else if ( show )
m_dontPreview.remove( preview );
@@ -409,7 +409,7 @@ void KonqPropsView::setShowingPreview( const TQString &preview, bool show )
//Audio is special-cased, as we use a binary setting
//for it to get it to follow the defaults right.
- bool audioEnabled = !m_dontPreview.tqcontains("audio/");
+ bool audioEnabled = !m_dontPreview.contains("audio/");
//Don't write it out into the DontPreview line
if (!audioEnabled)
@@ -474,7 +474,7 @@ void KonqPropsView::setBgColor( const TQColor & color )
const TQColor & KonqPropsView::bgColor( TQWidget * widget ) const
{
if ( !m_bgColor.isValid() )
- return widget->tqcolorGroup().base();
+ return widget->colorGroup().base();
else
return m_bgColor;
}
@@ -501,7 +501,7 @@ void KonqPropsView::setTextColor( const TQColor & color )
const TQColor & KonqPropsView::textColor( TQWidget * widget ) const
{
if ( !m_textColor.isValid() )
- return widget->tqcolorGroup().text();
+ return widget->colorGroup().text();
else
return m_textColor;
}
@@ -567,10 +567,10 @@ const TQStringList& KonqPropsView::previewSettings()
for ( KTrader::OfferList::ConstIterator it = plugins.begin(); it != plugins.end(); ++it )
{
TQString name = (*it)->desktopEntryName();
- if ( ! m_dontPreview.tqcontains(name) )
+ if ( ! m_dontPreview.contains(name) )
d->previewsToShow->append( name );
}
- if ( ! m_dontPreview.tqcontains( "audio/" ) )
+ if ( ! m_dontPreview.contains( "audio/" ) )
d->previewsToShow->append( "audio/" );
}
}
diff --git a/libkonq/konq_propsview.h b/libkonq/konq_propsview.h
index a1d397d18..c69b97966 100644
--- a/libkonq/konq_propsview.h
+++ b/libkonq/konq_propsview.h
@@ -107,7 +107,7 @@ public:
void setShowingPreview( const TQString &preview, bool show );
void setShowingPreview( bool show );
- bool isShowingPreview( const TQString &preview ) const { return ! m_dontPreview.tqcontains(preview); }
+ bool isShowingPreview( const TQString &preview ) const { return ! m_dontPreview.contains(preview); }
bool isShowingPreview();
const TQStringList &previewSettings();
@@ -133,7 +133,7 @@ protected:
TQString currentGroup() const {
return isDefaultProperties() ?
- TQString::tqfromLatin1("Settings") : TQString::tqfromLatin1("URL properties");
+ TQString::fromLatin1("Settings") : TQString::fromLatin1("URL properties");
}
private:
diff --git a/libkonq/konq_settings.cc b/libkonq/konq_settings.cc
index b9cf41503..d48c7af10 100644
--- a/libkonq/konq_settings.cc
+++ b/libkonq/konq_settings.cc
@@ -146,10 +146,10 @@ bool KonqFMSettings::shouldEmbed( const TQString & serviceType ) const
kdDebug(1203) << "KonqFMSettings::shouldEmbed : serviceTypeGroup=" << serviceTypeGroup << endl;
if ( serviceTypeGroup == "inode" || serviceTypeGroup == "Browser" || serviceTypeGroup == "Konqueror" )
return true; //always embed mimetype inode/*, Browser/* and Konqueror/*
- TQMap<TQString, TQString>::ConstIterator it = m_embedMap.find( TQString::tqfromLatin1("embed-")+serviceTypeGroup );
+ TQMap<TQString, TQString>::ConstIterator it = m_embedMap.find( TQString::fromLatin1("embed-")+serviceTypeGroup );
if ( it != m_embedMap.end() ) {
kdDebug(1203) << "KonqFMSettings::shouldEmbed: " << it.data() << endl;
- return it.data() == TQString::tqfromLatin1("true");
+ return it.data() == TQString::fromLatin1("true");
}
// 3 - if no config found, use default.
// Note: if you change those defaults, also change kcontrol/filetypes/typeslistitem.cpp !
diff --git a/libkonq/konq_undo.cc b/libkonq/konq_undo.cc
index b8858a2b2..91eece83b 100644
--- a/libkonq/konq_undo.cc
+++ b/libkonq/konq_undo.cc
@@ -317,7 +317,7 @@ void KonqUndoManager::undo()
}
else if ( (*it).m_link )
{
- if ( !d->m_fileCleanupStack.tqcontains( (*it).m_dst ) )
+ if ( !d->m_fileCleanupStack.contains( (*it).m_dst ) )
d->m_fileCleanupStack.prepend( (*it).m_dst );
if ( d->m_current.m_type != KonqCommand::MOVE )
@@ -339,7 +339,7 @@ void KonqUndoManager::undo()
KURL::List::ConstIterator it = d->m_current.m_src.begin();
KURL::List::ConstIterator end = d->m_current.m_src.end();
for (; it != end; ++it )
- if ( !d->m_dirStack.tqcontains( *it) )
+ if ( !d->m_dirStack.contains( *it) )
d->m_dirStack.push( *it );
}
*/
@@ -652,13 +652,13 @@ TQDataStream &operator>>( TQDataStream &stream, KonqBasicOperation &op )
TQDataStream &operator<<( TQDataStream &stream, const KonqCommand &cmd )
{
- stream << cmd.m_valid << (TQ_INT8)cmd.m_type << cmd.m_opStack << cmd.m_src << cmd.m_dst;
+ stream << cmd.m_valid << (Q_INT8)cmd.m_type << cmd.m_opStack << cmd.m_src << cmd.m_dst;
return stream;
}
TQDataStream &operator>>( TQDataStream &stream, KonqCommand &cmd )
{
- TQ_INT8 type;
+ Q_INT8 type;
stream >> cmd.m_valid >> type >> cmd.m_opStack >> cmd.m_src >> cmd.m_dst;
cmd.m_type = static_cast<KonqCommand::Type>( type );
return stream;
diff --git a/libkonq/konqbookmarkmanager.h b/libkonq/konqbookmarkmanager.h
index a45878562..9774d92e9 100644
--- a/libkonq/konqbookmarkmanager.h
+++ b/libkonq/konqbookmarkmanager.h
@@ -11,7 +11,7 @@ public:
static KBookmarkManager * self() {
if ( !s_bookmarkManager )
{
- TQString bookmarksFile = locateLocal("data", TQString::tqfromLatin1("konqueror/bookmarks.xml"));
+ TQString bookmarksFile = locateLocal("data", TQString::fromLatin1("konqueror/bookmarks.xml"));
s_bookmarkManager = KBookmarkManager::managerForFile( bookmarksFile );
}
return s_bookmarkManager;
diff --git a/libkonq/favicons/favicons.cpp b/libkonq/favicons/favicons.cpp
index 2a0723b1b..82b4aeb17 100644
--- a/libkonq/favicons/favicons.cpp
+++ b/libkonq/favicons/favicons.cpp
@@ -181,7 +181,7 @@ void FaviconsModule::downloadHostIcon(const KURL &url)
void FaviconsModule::startDownload(const TQString &hostOrURL, bool isHost, const KURL &iconURL)
{
- if (d->failedDownloads.tqcontains(iconURL.url()))
+ if (d->failedDownloads.contains(iconURL.url()))
return;
KIO::Job *job = KIO::get(iconURL, false, false);
@@ -222,7 +222,7 @@ void FaviconsModule::slotResult(KIO::Job *job)
io.setIODevice(&buffer);
io.setParameters("size=16");
// Check here too, the job might have had no error, but the downloaded
// file tqcontains just a 404 message sent with a 200 status.
// microsoft.com does that... (malte)
if (io.read())
{
@@ -222,7 +222,7 @@ void FaviconsModule::slotResult(KIO::Job *job)
io.setParameters("size=16");
// Check here too, the job might have had no error, but the downloaded
- // file tqcontains just a 404 message sent with a 200 status.
+ // file contains just a 404 message sent with a 200 status.
// microsoft.com does that... (malte)
if (io.read())
diff --git a/libkonq/konq_iconviewwidget.cc b/libkonq/konq_iconviewwidget.cc
index 7145c009c..0ce2ca346 100644
--- a/libkonq/konq_iconviewwidget.cc
+++ b/libkonq/konq_iconviewwidget.cc
@@ -151,7 +151,7 @@ KonqIconViewWidget::KonqIconViewWidget( TQWidget * parent, const char * name, WF
m_LineupMode = LineupBoth;
// emit our signals
slotSelectionChanged();
- m_iconPositionGroupPrefix = TQString::tqfromLatin1( "IconPosition::" );
+ m_iconPositionGroupPrefix = TQString::fromLatin1( "IconPosition::" );
KonqUndoManager::incRef();
}
@@ -308,7 +308,7 @@ void KonqIconViewWidget::slotOnItem( TQIconViewItem *_item )
if (!hasPixmap && backgroundMode() != NoBackground)
d->m_movie->setBackgroundColor( viewport()->backgroundColor() );
d->m_movie->connectUpdate( this, TQT_SLOT( slotMovieUpdate(const TQRect &) ) );
- d->m_movie->connecttqStatus( this, TQT_SLOT( slotMovietqStatus(int) ) );
+ d->m_movie->connectStatus( this, TQT_SLOT( slotMovieStatus(int) ) );
d->movieFileName = d->pActiveItem->mouseOverAnimation();
d->pActiveItem->setAnimated( true );
}
@@ -331,7 +331,7 @@ void KonqIconViewWidget::slotOnItem( TQIconViewItem *_item )
else // No change in current item
{
// No effect. If we want to underline on hover, we should
// force the IVI to tqrepaint here, though!
d->pActiveItem = 0L;
d->pFileTip->setItem( 0L );
}
@@ -346,10 +346,10 @@ void KonqIconViewWidget::slotOnItem( TQIconViewItem *_item )
// ## shouldn't this be disabled during rectangular selection too ?
if (d->bSoundPreviews && d->pSoundPlayer &&
- d->pSoundPlayer->mimeTypes().tqcontains(
+ d->pSoundPlayer->mimeTypes().contains(
item->item()->mimetype())
&& KGlobalSettings::showFilePreview(item->item()->url())
- && tqtopLevelWidget() == kapp->activeWindow())
+ && topLevelWidget() == kapp->activeWindow())
{
d->pSoundItem = item;
d->bSoundItemClicked = false;
@@ -478,11 +478,11 @@ void KonqIconViewWidget::slotMovieUpdate( const TQRect& rect )
}
d->pActiveItem->setPixmapDirect( frame, false, false /*no redraw*/ );
TQRect pixRect = d->pActiveItem->pixmapRect(false);
- tqrepaintContents( pixRect.x() + rect.x(), pixRect.y() + rect.y(), rect.width(), rect.height(), false );
+ repaintContents( pixRect.x() + rect.x(), pixRect.y() + rect.y(), rect.width(), rect.height(), false );
}
}
-void KonqIconViewWidget::slotMovietqStatus( int status )
+void KonqIconViewWidget::slotMovieStatus( int status )
{
if ( status < 0 ) {
// Error playing the MNG -> forget about it and do normal iconeffect
@@ -648,9 +648,9 @@ void KonqIconViewWidget::setIcons( int size, const TQStringList& stopImagePrevie
}
bool stopAll = !stopImagePreviewFor.isEmpty() && stopImagePreviewFor.first() == "*";
- // Disable tqrepaints that can be triggered by ivi->setIcon(). Since icons are
+ // Disable repaints that can be triggered by ivi->setIcon(). Since icons are
// resized in-place, if the icon size is increasing it can happens that the right
// or bottom icons exceed the size of the viewport.. here we prevent the tqrepaint
// event that will be triggered in that case.
bool prevUpdatesState = viewport()->isUpdatesEnabled();
viewport()->setUpdatesEnabled( false );
@@ -669,7 +669,7 @@ void KonqIconViewWidget::setIcons( int size, const TQStringList& stopImagePrevie
ivi->setIcon( size, ivi->state(), true, false );
}
else
- ivi->tqinvalidateThumb( ivi->state(), true );
+ ivi->invalidateThumb( ivi->state(), true );
}
// Restore viewport update to previous state
@@ -677,7 +677,7 @@ void KonqIconViewWidget::setIcons( int size, const TQStringList& stopImagePrevie
if ( ( sizeChanged || previewSizeChanged || oldGridX != gridX() ||
!stopImagePreviewFor.isEmpty() ) && autoArrange() )
- arrangeItemsInGrid( true ); // take new grid into account and tqrepaint
+ arrangeItemsInGrid( true ); // take new grid into account and repaint
else
viewport()->update(); //Repaint later..
}
@@ -692,7 +692,7 @@ bool KonqIconViewWidget::mimeTypeMatch( const TQString& mimeType, const TQString
return true;
// Support for *mt == "image/*"
TQString tmp( mimeType );
- if ( (*mt).endsWith("*") && tmp.tqreplace(TQRegExp("/.*"), "/*") == (*mt) )
+ if ( (*mt).endsWith("*") && tmp.replace(TQRegExp("/.*"), "/*") == (*mt) )
return true;
if ( (*mt) == "text/plain" )
{
@@ -830,7 +830,7 @@ void KonqIconViewWidget::startImagePreview( const TQStringList &, bool force )
return;
}
- if ((d->bSoundPreviews = d->previewSettings.tqcontains( "audio/" )) &&
+ if ((d->bSoundPreviews = d->previewSettings.contains( "audio/" )) &&
!d->pSoundPlayer)
{
KLibFactory *factory = KLibLoader::self()->factory("konq_sound");
@@ -995,7 +995,7 @@ void KonqIconViewWidget::contentsDragEnterEvent( TQDragEnterEvent *e )
{
if ( e->provides( "text/uri-list" ) )
{
- TQByteArray payload = e->tqencodedData( "text/uri-list" );
+ TQByteArray payload = e->encodedData( "text/uri-list" );
if ( !payload.size() )
kdError() << "Empty data !" << endl;
// Cache the URLs, since we need them every time we move over a file
@@ -1221,7 +1221,7 @@ void KonqIconViewWidget::contentsMouseMoveEvent( TQMouseEvent *e )
// The following call is SO expensive (the ::widgetAt call eats up to 80%
// of the mouse move cpucycles!), so it's mandatory to place that function
// under strict checks, such as d->pSoundPlayer->isPlaying()
- if ( TQApplication::widgetAt( TQCursor::pos() ) != tqtopLevelWidget() )
+ if ( TQApplication::widgetAt( TQCursor::pos() ) != topLevelWidget() )
{
if (d->pSoundPlayer)
d->pSoundPlayer->stop();
@@ -1249,7 +1249,7 @@ void KonqIconViewWidget::contentsDropEvent( TQDropEvent * ev )
if ( !i && (ev->action() == TQDropEvent::Copy || ev->action() == TQDropEvent::Link)
&& ev->source() && ev->source() == viewport())
{
- // First we need to call TQIconView though, to clear the drag tqshape
+ // First we need to call TQIconView though, to clear the drag shape
bool bMovable = itemsMovable();
setItemsMovable(false); // hack ? call it what you want :-)
KIconView::contentsDropEvent( ev );
@@ -1290,7 +1290,7 @@ void KonqIconViewWidget::doubleClickTimeout()
if ( url.isLocalFile() && (url.directory(false) == KGlobalSettings::trashPath() || url.path(1).startsWith(KGlobalSettings::trashPath())))
brenameTrash = true;
- if ( url.isLocalFile() && !brenameTrash && d->renameItem && m_pSettings->renameIconDirectly() && e.button() == LeftButton && item->textRect( false ).tqcontains(e.pos()))
+ if ( url.isLocalFile() && !brenameTrash && d->renameItem && m_pSettings->renameIconDirectly() && e.button() == LeftButton && item->textRect( false ).contains(e.pos()))
{
if( d->pActivateDoubleClick->isActive () )
d->pActivateDoubleClick->stop();
@@ -1368,7 +1368,7 @@ void KonqIconViewWidget::contentsMousePressEvent( TQMouseEvent *e )
bool brenameTrash =false;
if ( url.isLocalFile() && (url.directory(false) == KGlobalSettings::trashPath() || url.path(1).startsWith(KGlobalSettings::trashPath())))
brenameTrash = true;
- if ( !brenameTrash && !KGlobalSettings::singleClick() && m_pSettings->renameIconDirectly() && e->button() == LeftButton && item->textRect( false ).tqcontains(e->pos())&& !d->firstClick && url.isLocalFile() && (!url.protocol().find("device", 0, false)==0))
+ if ( !brenameTrash && !KGlobalSettings::singleClick() && m_pSettings->renameIconDirectly() && e->button() == LeftButton && item->textRect( false ).contains(e->pos())&& !d->firstClick && url.isLocalFile() && (!url.protocol().find("device", 0, false)==0))
{
d->firstClick = true;
d->mousePos = e->pos();
@@ -1703,7 +1703,7 @@ void KonqIconViewWidget::lineupIcons()
}
// Perform the actual moving
- TQRegion tqrepaintRegion;
+ TQRegion repaintRegion;
TQValueList<TQIconViewItem*> movedItems;
for ( i = 0; i < nx; i++ ) {
@@ -1722,7 +1722,7 @@ void KonqIconViewWidget::lineupIcons()
movedItems.prepend( item );
item->move( newX, newY );
if ( item->rect() != oldRect )
- tqrepaintRegion = tqrepaintRegion.unite( oldRect );
+ repaintRegion = repaintRegion.unite( oldRect );
}
}
delete bin;
@@ -1730,20 +1730,20 @@ void KonqIconViewWidget::lineupIcons()
}
}
- // tqrepaint
+ // repaint
if ( newItemWidth )
updateContents();
else {
- // Repaint only tqrepaintRegion...
- TQMemArray<TQRect> rects = tqrepaintRegion.rects();
+ // Repaint only repaintRegion...
+ TQMemArray<TQRect> rects = repaintRegion.rects();
for ( uint l = 0; l < rects.count(); l++ ) {
kdDebug( 1203 ) << "Repainting (" << rects[l].x() << ","
<< rects[l].y() << ")\n";
- tqrepaintContents( rects[l], false );
+ repaintContents( rects[l], false );
}
// Repaint icons that were moved
while ( !movedItems.isEmpty() ) {
- tqrepaintItem( movedItems.first() );
+ repaintItem( movedItems.first() );
movedItems.remove( movedItems.first() );
}
}
@@ -1760,7 +1760,7 @@ void KonqIconViewWidget::lineupIcons( TQIconView::Arrangement arrangement )
gridValues( &x0, &y0, &dx, &dy, &nxmax, &nymax );
int textHeight = iconTextHeight() * fontMetrics().height();
- TQRegion tqrepaintRegion;
+ TQRegion repaintRegion;
TQValueList<TQIconViewItem*> movedItems;
int nx = 0, ny = 0;
@@ -1775,7 +1775,7 @@ void KonqIconViewWidget::lineupIcons( TQIconView::Arrangement arrangement )
movedItems.prepend( item );
item->move( newX, newY );
if ( item->rect() != oldRect )
- tqrepaintRegion = tqrepaintRegion.unite( oldRect );
+ repaintRegion = repaintRegion.unite( oldRect );
}
if ( arrangement == TQIconView::LeftToRight ) {
nx++;
@@ -1793,16 +1793,16 @@ void KonqIconViewWidget::lineupIcons( TQIconView::Arrangement arrangement )
}
}
- // Repaint only tqrepaintRegion...
- TQMemArray<TQRect> rects = tqrepaintRegion.rects();
+ // Repaint only repaintRegion...
+ TQMemArray<TQRect> rects = repaintRegion.rects();
for ( uint l = 0; l < rects.count(); l++ ) {
kdDebug( 1203 ) << "Repainting (" << rects[l].x() << ","
<< rects[l].y() << ")\n";
- tqrepaintContents( rects[l], false );
+ repaintContents( rects[l], false );
}
// Repaint icons that were moved
while ( !movedItems.isEmpty() ) {
- tqrepaintItem( movedItems.first() );
+ repaintItem( movedItems.first() );
movedItems.remove( movedItems.first() );
}
}
@@ -1916,7 +1916,7 @@ void KonqIconViewWidget::updatePreviewMimeTypes()
KTrader::OfferList::ConstIterator it;
for ( it = plugins.begin(); it != plugins.end(); ++it ) {
- if ( d->previewSettings.tqcontains((*it)->desktopEntryName()) ) {
+ if ( d->previewSettings.contains((*it)->desktopEntryName()) ) {
TQStringList mimeTypes = (*it)->property("MimeTypes").toStringList();
for (TQStringList::ConstIterator mt = mimeTypes.begin(); mt != mimeTypes.end(); ++mt)
d->pPreviewMimeTypes->append(*mt);
@@ -331,7 +331,7 @@ void KonqIconViewWidget::slotOnItem( TQIconViewItem *_item )
{
// No effect. If we want to underline on hover, we should
- // force the IVI to tqrepaint here, though!
+ // force the IVI to repaint here, though!
d->pActiveItem = 0L;
d->pFileTip->setItem( 0L );
@@ -648,9 +648,9 @@ void KonqIconViewWidget::setIcons( int size, const TQStringList& stopImagePrevie
// resized in-place, if the icon size is increasing it can happens that the right
- // or bottom icons exceed the size of the viewport.. here we prevent the tqrepaint
+ // or bottom icons exceed the size of the viewport.. here we prevent the repaint
// event that will be triggered in that case.
bool prevUpdatesState = viewport()->isUpdatesEnabled();
diff --git a/libkonq/konq_popupmenu.h b/libkonq/konq_popupmenu.h
index f1dc5ab63..ee528bc9e 100644
--- a/libkonq/konq_popupmenu.h
+++ b/libkonq/konq_popupmenu.h
@@ -69,7 +69,7 @@ public:
// WARNING: bitfield. Next item is 8
/**
* @deprecated lacks tqparentWidget pointer, and
* uses bool instead of KonqPopupFlags enum,
* might do strange things with the 'new window' action.
*/
@@ -89,7 +89,7 @@ public:
KURL viewURL,
KActionCollection & actions,
KNewMenu * newMenu,
- TQWidget * tqparentWidget,
+ TQWidget * parentWidget,
bool showPropertiesAndFileType = true ) KDE_DEPRECATED;
/**
@@ -99,7 +99,7 @@ public:
* @param viewURL the URL shown in the view, to test for RMB click on view background
* @param actions list of actions the caller wants to see in the menu
* @param newMenu "New" menu, shared with the File menu, in konqueror
* @param tqparentWidget the widget we're showing this popup for. Helps destroying
* the popup if the widget is destroyed before the popup.
* @param kpf flags from the KonqPopupFlags enum, set by the calling application
* @param f flags from the BrowserExtension enum, set by the calling part
@@ -117,7 +117,7 @@ public:
const KURL& viewURL,
KActionCollection & actions,
KNewMenu * newMenu,
- TQWidget * tqparentWidget,
+ TQWidget * parentWidget,
KonqPopupFlags kpf,
KParts::BrowserExtension::PopupFlags f /*= KParts::BrowserExtension::DefaultPopupItems*/);
@@ -177,7 +177,7 @@ protected:
KActionCollection m_ownActions;
private:
- void init (TQWidget * tqparentWidget, KonqPopupFlags kpf, KParts::BrowserExtension::PopupFlags itemFlags);
+ void init (TQWidget * parentWidget, KonqPopupFlags kpf, KParts::BrowserExtension::PopupFlags itemFlags);
void setup(KonqPopupFlags kpf);
void addPlugins( );
int insertServicesSubmenus(const TQMap<TQString, ServiceList>& list, TQDomElement& menu, bool isBuiltin);
@@ -69,7 +69,7 @@ public:
// WARNING: bitfield. Next item is 8
/**
- * @deprecated lacks tqparentWidget pointer, and
+ * @deprecated lacks parentWidget pointer, and
* uses bool instead of KonqPopupFlags enum,
* might do strange things with the 'new window' action.
@@ -99,7 +99,7 @@ public:
* @param actions list of actions the caller wants to see in the menu
* @param newMenu "New" menu, shared with the File menu, in konqueror
- * @param tqparentWidget the widget we're showing this popup for. Helps destroying
+ * @param parentWidget the widget we're showing this popup for. Helps destroying
* the popup if the widget is destroyed before the popup.
* @param kpf flags from the KonqPopupFlags enum, set by the calling application